Documentation
¶
Index ¶
- type Chart
- type ChartsResult
- type CompareEnvironments
- type CompareEnvsQuery
- type CompareEnvsResponse
- type ConfigMap
- type CopyVariableValue
- type DataElement
- type DataVariableElement
- type DefaultRepoRequest
- type DepAnalyse
- type DepAnalyseRequest
- type DepLink
- type Deployment
- type DeploymentResponse
- type Deployments
- type DockerRepo
- type EnvResult
- type Environment
- type EnvironmentName
- type EnvironmentsDiff
- type FilterField
- type GetChartRequest
- type GetRevisionRequest
- type GetSettingsListRequest
- type GetUserPolicyByEnvironmentRequest
- type HistoryRequest
- type InstallArguments
- type InstallPayload
- type InvalidVariable
- type InvalidVariablesResult
- type LightUser
- type ListDockerRepositoryResponse
- type ListDockerTagsRequest
- type ListDockerTagsResult
- type ManifestHistory
- type ManifestResult
- type MultipleInstallPayload
- type NewVariable
- type Node
- type Notes
- type Pod
- type PodResult
- type Principal
- type Product
- type ProductRequestReponse
- type ProductVersion
- type ProductVersionRequestReponse
- type ProductVersionService
- type ProductVersionServiceRequestReponse
- type RabbitInstallPayload
- type ReleaseDeleteRequest
- type Repository
- type RepositoryResult
- type RequestDeployment
- type RequestDeployments
- type ResponseDeploymentResponse
- type SaveCompareEnvQuery
- type SearchResult
- type SecurityOperation
- type SecurityOperationResponse
- type Service
- type ServiceResult
- type Settings
- type SettingsList
- type Solution
- type SolutionChart
- type SolutionChartResult
- type SolutionResult
- type TagResponse
- type TagsResult
- type TrafficReleaseRequest
- type TrafficRequest
- type User
- type UserEmail
- type UserEnvRole
- type UserEnvironmentRole
- type UserResult
- type V1Compatibility
- type ValueRule
- type ValueRuleReponse
- type Variable
- type VariableData
- type VariableRule
- type VariableRuleReponse
- type VariablesByChartAndEnvironment
- type VariablesDefault
- type VariablesResult
- type WebHook
- type WebHookNewReleasePostPayload
- type WebHookPostPayload
- type WebHookReponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Chart ¶
type Chart struct {
Repo string `json:"repo"`
Name string `json:"chartName"`
Version string `json:"chartVersion"`
}
Chart struct
type ChartsResult ¶
type ChartsResult struct {
Charts []SearchResult `json:"charts"`
}
ChartsResult Model
type CompareEnvironments ¶
type CompareEnvironments struct {
SourceEnvID int `json:"sourceEnvId"`
TargetEnvID int `json:"targetEnvId"`
ExceptCharts []string `json:"exceptCharts"`
OnlyCharts []string `json:"onlyCharts"`
ExceptFields []string `json:"exceptFields"`
OnlyFields []string `json:"onlyFields"`
CustomFields []FilterField `json:"customFields"`
FilterOnlyExceptChart int `json:"filterOnlyExceptChart"`
FilterOnlyExceptField int `json:"filterOnlyExceptField"`
SelectedFilterFieldType selectItem `json:"selectedFilterFieldType"`
GlobalFilter string `json:"globalFilter"`
}
CompareEnvironments Model Payload
type CompareEnvsQuery ¶
type CompareEnvsQuery struct {
gorm.Model
Name string `json:"name"`
UserID int `json:"userId"`
Query postgres.Jsonb `json:"query"`
}
CompareEnvsQuery CompareEnvsQuery
type CompareEnvsResponse ¶
type CompareEnvsResponse struct {
List []EnvironmentsDiff `json:"list"`
}
CompareEnvsResponse CompareEnvsResponse
type CopyVariableValue ¶
type CopyVariableValue struct {
SrcVarID uint `json:"srcVarId"`
TarEnvID uint `json:"tarEnvId"`
TarVarID uint `json:"tarVarId"`
NewValue string `json:"newValue"`
}
CopyVariableValue CopyVariableValue
type DataElement ¶
type DataElement struct {
Data Environment `json:"data"`
}
DataElement dataElement
type DataVariableElement ¶
type DataVariableElement struct {
Data Variable `json:"data"`
}
DataVariableElement dataElement
type DefaultRepoRequest ¶
type DefaultRepoRequest struct {
Reponame string `json:"reponame"`
}
DefaultRepoRequest struct
type DepAnalyse ¶
DepAnalyse struct
type DepAnalyseRequest ¶
type DepAnalyseRequest struct {
EnvironmentID int `json:"environmentId"`
ChartName string `json:"chartName"`
Tag string `json:"tag"`
}
DepAnalyseRequest struct
type Deployment ¶
type Deployment struct {
gorm.Model
RequestDeploymentID uint `json:"request_deployment_id"`
EnvironmentID uint `json:"environment_id"`
Chart string `json:"chart"`
ChartVersion string `json:"chartVersion"`
Processed bool `json:"processed"`
Success bool `json:"success"`
Message string `json:"message"`
DockerVersion string `json:"dockerVersion"`
}
Deployment struct
type DeploymentResponse ¶
type DeploymentResponse struct {
Count int64 `json:"count"`
TotalPages int `json:"total_pages"`
Data []Deployments `json:"data"`
}
DeploymentResponse struct response /deployments GET
type Deployments ¶
type Deployments struct {
ID uint
CreatedAt time.Time
UpdatedAt time.Time
DeletedAt *time.Time
RequestDeploymentID uint `json:"request_deployment_id"`
Environment string `json:"environment"`
Chart string `json:"chart"`
Success bool `json:"success"`
Message string `json:"message"`
Processed bool `json:"processed"`
DockerVersion string `json:"dockerVersion"`
ChartVersion string `json:"chartVersion"`
}
Deployments struct to fill with query result to response /requestDeployments GET
type DockerRepo ¶
type DockerRepo struct {
gorm.Model
Host string `json:"host"`
Username string `json:"username"`
Password string `json:"password"`
}
DockerRepo structure
type Environment ¶
type Environment struct {
gorm.Model
Group string `json:"group"`
Name string `json:"name"`
ClusterURI string `json:"cluster_uri"`
CACertificate string `json:"ca_certificate"`
Token string `json:"token"`
Namespace string `json:"namespace"`
Gateway string `json:"gateway"`
ProductVersion string `json:"productVersion"`
CurrentRelease string `json:"currentRelease"`
}
Environment - Environment Model
type EnvironmentName ¶
EnvironmentName is a struct to be used with deployments payload response
type EnvironmentsDiff ¶
type EnvironmentsDiff struct {
SourceEnvID int `json:"sourceEnvId"`
TargetEnvID int `json:"targetEnvId"`
SourceScope string `json:"sourceScope"`
TargetScope string `json:"targetScope"`
SourceName string `json:"sourceName"`
TargetName string `json:"targetName"`
SourceValue string `json:"sourceValue"`
TargetValue string `json:"targetValue"`
SourceVarID string `json:"sourceVarId"`
TargetVarID string `json:"targetVarId"`
}
EnvironmentsDiff Model Response
type FilterField ¶
type FilterField struct {
FilterType string `json:"filterType"`
FilterValue string `json:"filterValue"`
}
FilterField Filters the CompareEnvironments result
type GetChartRequest ¶
type GetChartRequest struct {
ChartName string `json:"chartName"`
ChartVersion string `json:"chartVersion"`
}
GetChartRequest struct
type GetRevisionRequest ¶
type GetRevisionRequest struct {
EnvironmentID int `json:"environmentID"`
ReleaseName string `json:"releaseName"`
Revision int `json:"revision"`
}
GetRevisionRequest Structure
type GetSettingsListRequest ¶
type GetSettingsListRequest struct {
List []string
}
GetSettingsListRequest struct
type GetUserPolicyByEnvironmentRequest ¶
type GetUserPolicyByEnvironmentRequest struct {
Email string `json:"email"`
EnvironmentID int `json:"environmentId"`
}
GetUserPolicyByEnvironmentRequest - GetUserPolicyByEnvironmentRequest
type HistoryRequest ¶
type HistoryRequest struct {
EnvironmentID int `json:"environmentID"`
ReleaseName string `json:"releaseName"`
}
HistoryRequest Structure
type InstallArguments ¶
InstallArguments Method
type InstallPayload ¶
type InstallPayload struct {
EnvironmentID int `json:"environmentId"`
Chart string `json:"chart"`
ChartVersion string `json:"chartVersion"`
Name string `json:"name"`
}
InstallPayload Struct
type InvalidVariable ¶
type InvalidVariable struct {
Scope string `json:"scope"`
Name string `json:"name"`
Value string `json:"value"`
VariableRule string `json:"variableRule"`
RuleType string `json:"ruleType"`
ValueRule string `json:"valueRule"`
}
InvalidVariable Model
type InvalidVariablesResult ¶
type InvalidVariablesResult struct {
InvalidVariables []InvalidVariable
}
InvalidVariablesResult Model
type ListDockerRepositoryResponse ¶
type ListDockerRepositoryResponse struct {
Repositories []DockerRepo `json:"repositories"`
}
ListDockerRepositoryResponse structure
type ListDockerTagsRequest ¶
ListDockerTagsRequest structure
type ListDockerTagsResult ¶
type ListDockerTagsResult struct {
TagResponse []TagResponse `json:"tags"`
}
ListDockerTagsResult structure
type ManifestHistory ¶
type ManifestHistory struct {
V1Compatibility string `json:"v1Compatibility"`
}
ManifestHistory structure
type ManifestResult ¶
type ManifestResult struct {
History []ManifestHistory `json:"history"`
}
ManifestResult structure
type MultipleInstallPayload ¶
type MultipleInstallPayload struct {
ProductVersionID int `json:"productVersionId"`
EnvironmentIDs []int `json:"environmentIds"`
Deployables []InstallPayload `json:"deployables"`
}
MultipleInstallPayload struct
type NewVariable ¶
type NewVariable struct {
Scope string `json:"scope"`
ChartVersion string `json:"chartVersion"`
Name string `json:"name"`
Value string `json:"value"`
Secret bool `json:"secret"`
Description string `json:"description"`
EnvironmentID int `json:"environmentId"`
New bool `json:"new"`
}
NewVariable Structure
type Node ¶
type Node struct {
ID string `json:"id"`
Color string `json:"color"`
SymbolType string `json:"symbolType"`
Svg string `json:"svg"`
}
Node struct
type Notes ¶
type Notes struct {
gorm.Model
ServiceName string `json:"serviceName"`
Text string `gorm:"type:text" json:"text"`
}
Notes - Notes Model
type Pod ¶
type Pod struct {
Name string `json:"name"`
Image string `json:"image"`
Ready string `json:"ready"`
Status string `json:"status"`
Restarts int `json:"restarts"`
Age string `json:"age"`
}
Pod structure
type Product ¶
type Product struct {
gorm.Model
Name string `json:"name"`
ValidateReleases bool `json:"validateReleases"`
}
Product struct
type ProductRequestReponse ¶
type ProductRequestReponse struct {
List []Product `json:"list"`
}
ProductRequestReponse struct
type ProductVersion ¶
type ProductVersion struct {
gorm.Model
ProductID int `json:"productId"`
Date time.Time `json:"date"`
Version string `json:"version"`
BaseRelease int `gorm:"-" json:"baseRelease"`
Locked bool `json:"locked"`
HotFix bool `json:"hotFix"`
}
ProductVersion struct
type ProductVersionRequestReponse ¶
type ProductVersionRequestReponse struct {
List []ProductVersion `json:"list"`
}
ProductVersionRequestReponse struct
type ProductVersionService ¶
type ProductVersionService struct {
gorm.Model
ProductVersionID int `json:"productVersionId"`
ServiceName string `json:"serviceName"`
DockerImageTag string `json:"dockerImageTag"`
LatestVersion string `gorm:"-" json:"latestVersion"`
ChartLatestVersion string `gorm:"-" json:"chartLatestVersion"`
Notes string `json:"notes"`
}
ProductVersionService struct
type ProductVersionServiceRequestReponse ¶
type ProductVersionServiceRequestReponse struct {
List []ProductVersionService `json:"list"`
}
ProductVersionServiceRequestReponse struct
type RabbitInstallPayload ¶
type RabbitInstallPayload struct {
ProductVersionID int `json:"productVersionId"`
Environment Environment `json:"environment"`
Deployable InstallPayload `json:"deployable"`
}
RabbitInstallPayload -> Struct of data to post on queue to install
type ReleaseDeleteRequest ¶
type ReleaseDeleteRequest struct {
EnvironmentID int `json:"environmentID"`
ReleaseName string `json:"releaseName"`
Purge bool `json:"purge"`
}
ReleaseDeleteRequest Structure
type Repository ¶
type Repository struct {
Name string `json:"name"`
URL string `json:"url"`
Username string `json:"username"`
Password string `json:"password"`
}
Repository struct
type RepositoryResult ¶
type RepositoryResult struct {
Repositories []Repository `json:"repositories"`
}
RepositoryResult struct
type RequestDeployment ¶
type RequestDeployment struct {
gorm.Model
Success bool `json:"success"`
Processed bool `json:"processed"`
UserID uint `json:"user_id"`
}
RequestDeployment deployment requested from user
type RequestDeployments ¶
type RequestDeployments struct {
ID uint
CreatedAt time.Time
UpdatedAt time.Time
User string `json:"user"`
Success bool `json:"success"`
Processed bool `json:"processed"`
}
RequestDeployments struct to fill with query result to response /requestDeployments{id} GET
type ResponseDeploymentResponse ¶
type ResponseDeploymentResponse struct {
Count int64 `json:"count"`
TotalPages int `json:"total_pages"`
Data []RequestDeployments `json:"data"`
}
ResponseDeploymentResponse struct response /deployments GET
type SaveCompareEnvQuery ¶
type SaveCompareEnvQuery struct {
ID uint `json:"id"`
Name string `json:"name"`
UserEmail string `json:"userEmail"`
Data CompareEnvironments `json:"data"`
}
SaveCompareEnvQuery SaveCompareEnvQuery
type SearchResult ¶
type SearchResult struct {
Name string `json:"name"`
ChartVersion string `json:"chartVersion"`
AppVersion string `json:"appVersion"`
Description string `json:"description"`
}
SearchResult result
type SecurityOperation ¶
type SecurityOperation struct {
gorm.Model
Name string `json:"name"`
Policies pq.StringArray `gorm:"type:text[]" json:"policies" `
}
SecurityOperation - SecurityOperation
type SecurityOperationResponse ¶
type SecurityOperationResponse struct {
List []SecurityOperation `json:"list"`
}
SecurityOperationResponse - SecurityOperationResponse
type Service ¶
type Service struct {
Name string `json:"name"`
Type string `json:"type"`
ClusterIP string `json:"clusterIP"`
ExternalIP string `json:"externalIP"`
Ports string `json:"ports"`
Age string `json:"age"`
}
Service structure
type ServiceResult ¶
type ServiceResult struct {
Services []Service `json:"services"`
}
ServiceResult structure
type SolutionChart ¶
type SolutionChart struct {
gorm.Model
SolutionID int `json:"solution_id"`
ChartName string `json:"chartName"`
}
SolutionChart struct
type SolutionChartResult ¶
type SolutionChartResult struct {
List []SolutionChart `json:"list"`
}
SolutionChartResult struct
type SolutionResult ¶
type SolutionResult struct {
List []Solution `json:"list"`
}
SolutionResult struct
type TagResponse ¶
TagResponse Structure
type TrafficReleaseRequest ¶
TrafficReleaseRequest Structure
type TrafficRequest ¶
type TrafficRequest struct {
EnvironmentID int `json:"environmentId"`
Domain string `json:"domain"`
ServiceName string `json:"serviceName"`
ContextPath string `json:"contextPath"`
HeaderName string `json:"headerName"`
HeaderValue string `json:"headerValue"`
HeaderReleaseName string `json:"headerReleaseName"`
DefaultReleaseName string `json:"defaultReleaseName"`
Releases []TrafficReleaseRequest `json:"releases"`
}
TrafficRequest structure
type User ¶
type User struct {
gorm.Model
Email string `json:"email"`
DefaultEnvironmentID int `json:"defaultEnvironmentID"`
Environments []Environment `gorm:"many2many:user_environment;"`
}
User struct
type UserEnvRole ¶
UserEnvRole struct
type UserEnvironmentRole ¶
type UserEnvironmentRole struct {
gorm.Model
UserID uint `json:"userId"`
EnvironmentID uint `json:"environmentId"`
SecurityOperationID uint `json:"securityOperationId"`
}
UserEnvironmentRole UserEnvironmentRole
type V1Compatibility ¶
V1Compatibility structure
type ValueRule ¶
type ValueRule struct {
gorm.Model
Type string `json:"type"`
Value string `json:"value"`
VariableRuleID uint
}
ValueRule Structure
type ValueRuleReponse ¶
type ValueRuleReponse struct {
List []ValueRule `json:"list"`
}
ValueRuleReponse struct
type Variable ¶
type Variable struct {
gorm.Model
Scope string `json:"scope" gorm:"index:var_scope"`
ChartVersion string `gorm:"-" json:"chartVersion"`
Name string `json:"name" gorm:"index:var_name"`
Value string `json:"value"`
Secret bool `json:"secret"`
Description string `json:"description"`
EnvironmentID int `json:"environmentId"`
}
Variable Structure
type VariableRule ¶
type VariableRule struct {
gorm.Model
Name string `json:"name"`
ValueRules []*ValueRule `gorm:"foreignkey:VariableRuleID"`
}
VariableRule Structure
type VariableRuleReponse ¶
type VariableRuleReponse struct {
List []VariableRule `json:"list"`
}
VariableRuleReponse struct
type VariablesByChartAndEnvironment ¶
VariablesByChartAndEnvironment struct
type VariablesDefault ¶
VariablesDefault struct
type WebHook ¶
type WebHook struct {
gorm.Model
Name string `json:"name"`
Type string `json:"type"`
URL string `json:"url"`
EnvironmentID int `json:"environmentId"`
AdditionalData string `json:"additionalData"`
}
WebHook Structure
type WebHookNewReleasePostPayload ¶
type WebHookNewReleasePostPayload struct {
Environment string `json:"environment"`
ProductName string `json:"productName"`
Release string `json:"release"`
AdditionalData string `json:"additionalData"`
Services []string `json:"services"`
}
WebHookNewReleasePostPayload struct
type WebHookPostPayload ¶
type WebHookPostPayload struct {
Environment string `json:"environment"`
ProductName string `json:"productName"`
Release string `json:"release"`
}
WebHookPostPayload struct
type WebHookReponse ¶
type WebHookReponse struct {
List []WebHook `json:"list"`
}
WebHookReponse struct